<?php

declare(strict_types=1);

namespace Drupal\group_relationship_inheritance\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\BooleanCheckboxWidget;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the 'group_relationship_inheritance_checkbox' field widget.
 *
 * @FieldWidget(
 *   id = "group_relationship_inheritance_checkbox",
 *   label = @Translation("Group relationship inheritance"),
 *   field_types = {"group_relationship_inheritance"},
 * )
 */
final class CheckboxWidget extends BooleanCheckboxWidget {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'relate_referenced_entities_in_form' => FALSE,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $element['relate_referenced_entities_in_form'] = [
      '#type' => 'checkbox',
      '#title' => t('Relate each referenced entities with the same groups that this entity belongs.'),
      '#description' => t('This setting is not used when not using the form. It needs that content is available to the group type.'),
      '#default_value' => $this->getSetting('relate_referenced_entities_in_form'),
      '#weight' => -1,
    ];
    return $element + parent::settingsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $relate = $this->getSetting('relate_referenced_entities_in_form');
    $summary[] = t('Relate each referenced entities: @relate', [
      '@relate' => $relate ? t('Yes') : t('No'),
    ]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['value'] = $element + [
      '#type' => 'checkbox',
    // !empty($items[0]->value),
      '#default_value' => $this->getSetting('relate_referenced_entities_in_form'),
      '#weight' => -10,
    ];
    // Override the title from the incoming $element.
    if ($this->getSetting('display_label')) {
      $element['value']['#title'] = $this->fieldDefinition
        ->getLabel();
    }
    else {
      $element['value']['#title'] = $this->fieldDefinition
        ->getSetting('on_label');
    }
    // If the advanced settings tabs-set is available (normally rendered in the
    // second column on wide-resolutions), place the field as a details element
    // in this tab-set.
    if (isset($form['advanced'])) {
      $element += [
        '#type' => 'details',
        '#group' => 'advanced',
        #'#tree' => TRUE, // If not working try this
        '#weight' => -2,
        '#attributes' => ['class' => ['group-relationship-settings-form']],
      ];
      $element['#title'] = t('Group relationship settings');
    }
    $element['value']['#title_display'] = 'after';

    return $element;
  }

}
